// main.js

// modules pour contrôler la vie de l'application EmojiCode et créer une fenêtre de navigateur Chromium/NodeJS
const { app, BrowserWindow } = require('electron');
const emojiCodeStartPath = require('path');

const createWindow = () => {
    // création de la fenêtre de navigateur
    const emojiCodeStartWindow = new BrowserWindow({
        width: 800,
        height: 600,
        // on masque la barre de menu de l'application ElectronJS
        // si on veut y ré-accéder on utilisera la touche ALT du clavier pour l'afficher (ou la remasquer si affichée) une fois l'application lancée.
        autoHideMenuBar: true,
        // ajout d'un preloader, utilisé pour récupérer les versions des différents processus (process) depuis le fichier preload.js, dont on s'en sert depuis le fichier index.html
        webPreferences: {
            preload: emojiCodeStartPath.join(__dirname, '/_system/preload.js')
        }
    });
    
    // et on charge dans la fenêtre de navigateur ainsi créée le fichier d'interface HTML qui contient notre interface visuelle: index.html
    // étant le fichier HTML principal affiché à l'entrée de l'application EmojiCode
    emojiCodeStartWindow.loadFile('index.html');
    
    // utilisé pour afficher les Outils de Développement
    // DevTools pour debugguer l'application EmojiCode
    // emojiCodeStartWindow.webContents.openDevTools()
    
}

// méthode d'événement
// appellée quand le framework ElectronJS aura terminé de s'initialiser et sera prêt à l'emploi pour créer des fenêtres de navigateur
// NOTE - certaines APIs et fonctionnalités de Electron seront utilisables qu'après l'initilisation de cette méthode d'événement
app.whenReady().then(() => {
    createWindow();
    
    app.on('activate', () => {
        // compatibilité assurée avec macOS..
        // sur macOS il est fréquent de ré-créer une fenêtre dans une application ElectronJS quand l'icone du Dock macOS est cliqué et qu'il n'y a plus d'autres fenêtres ouvertes..
        // ce hack remplit cette tâche rébarbative
        if (BrowserWindow.getAllWindows().length === 0) {
            createWindow();
        }
    })
})

// méthode d'événement
// quand toutes les fenêtres d'une application ElectronJS sont fermées, alors, cela quittera aussi l'application EmojiCode
// excepté sur macOS (voir plus haut)
// dans le cas de macOS c'est fréquent pour les applications et leur barre de menu pour rester actives jusqu'à ce que l'utilisateur quittes explicitement avec la commande clavier CMD+Q
app.on('window-all-closed', () => {
    if (process.platform !== 'darwin') {
        app.quit();
    }
})

// dans ce fichier, à partir de cette ligne, se trouve tout le code de EmojiCode ou les chargeurs de Modules alternatifs utilisés dans EmojiCode

// chargement de l'encodeur et du décodeur (fonctions JS)
/* not used in that application:
  const { emojiCodeInto, emojiCodeFrom } = require('mapkeys.js');
*/
